# Generador de proyecto API para dealergeek

Generar release

```
python setup.py sdist
```

Subir a Pip

```
twine upload dist/*
```


## Use

### create a new project

```
dgx -c python-test
```


### delete a project

```
dgx -d python-test
```